@@ -105,8 +105,12 @@ feed.parseFriendsFeedUpdate = function(response, page) {
                         //do nothing, just skip that.
                     } else if (del.type === "checkin") {
                         page.deleteItem(del.id);
+                    } else if (del.type === "tip") {
+                        page.deleteItem(del.id);
                     } else if (del.type === "activity"){
                         page.deleteItem(del.id);
+                    } else if (del.type === "list") {
+                        page.deleteItem(del.id);
                     } else {
                         del.debugType = "feed-delete";
                         var deleteitem = {
